(context-strings test-sexpr-zloc)A series of string comments preceding the test sexpr.
A series of string comments preceding the test sexpr.
(expectation-data test-sexpr-zloc)Parse a string representing the expectation for a test expression and an
expression type, returning a vector of [type str] (or nil if none).
The expected result is designated by a =>-prefixed comment, either directly after or on a line following the test expression.
For example:
(+ 1 1) ;=> 2
(+ 1 1) ;;=> 2
(+ 1 1) ;; => 2
Parse a string representing the expectation for a test expression and an expression type, returning a vector of `[type str]` (or nil if none). The expected result is designated by a =>-prefixed comment, either directly after or on a line following the test expression. For example: (+ 1 1) ;=> 2 (+ 1 1) ;;=> 2 (+ 1 1) ;; => 2
(iterate1 f x)Like clojure.core/iterate, but stops at the first nil element.
Like `clojure.core/iterate`, but stops at the first `nil` element.
(pairs)Transducer from [a b c ... z] => [[a b] [b c] ... [z nil]].
Transducer from [a b c ... z] => [[a b] [b c] ... [z nil]].
(rct? zloc)Is the node at the zloc a ^:rct/test (comment ...) block?
Is the node at the `zloc` a ^:rct/test (comment ...) block?
(rsequence xform coll)Like (reverse (sequence xform coll)).
Like `(reverse (sequence xform coll))`.
(test-sexpr-zlocs rct-zloc)All sexpr-able nodes inside a rct form.
All sexpr-able nodes inside a rct form.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |